# `relationalai.clients.snowflake`

The `relationalai.clients.snowflake` module contains classes for working with
Snowflake data in a RelationalAI [model](../../Model/README.md).

- [`clients.snowflake.PrimaryKey`](./PrimaryKey.md)
- [`clients.snowflake.Snowflake`](./Snowflake.md)
- [`clients.snowflake.SnowflakeTable`](./SnowflakeTable/README.md)
  - [`clients.snowflake.SnowflakeTable.describe()`](./SnowflakeTable/describe.md)
  - [`clients.snowflake.SnowflakeTable.fqname()`](./SnowflakeTable/fqname.md)
  - [`clients.snowflake.SnowflakeTable.namespace()`](./SnowflakeTable/namespace.md)
